Rename the bitmap to axmap

It's not really a bitmap, it's a bitmap of bitmaps. Now named.

Signed-off-by: Jens Axboe <axboe@kernel.dk>
diff --git a/io_u.c b/io_u.c
index 2904ad4..006f2c9 100644
--- a/io_u.c
+++ b/io_u.c
@@ -10,7 +10,7 @@
 #include "verify.h"
 #include "trim.h"
 #include "lib/rand.h"
-#include "lib/bitmap.h"
+#include "lib/axmap.h"
 
 struct io_completion_data {
 	int nr;				/* input */
@@ -21,12 +21,12 @@
 };
 
 /*
  * The ->io_bitmap contains a map of blocks we have or have not done io
  * to yet. Used to make sure we cover the entire range in a fair fashion.
  */
 static int random_map_free(struct fio_file *f, const unsigned long long block)
 {
-	return !bitmap_isset(f->io_bitmap, block);
+	return !axmap_isset(f->io_axmap, block);
 }
 
 /*
@@ -43,7 +43,7 @@
 	nr_blocks = (io_u->buflen + min_bs - 1) / min_bs;
 
 	if (!(io_u->flags & IO_U_F_BUSY_OK))
-		nr_blocks = bitmap_set_nr(f->io_bitmap, block, nr_blocks);
+		nr_blocks = axmap_set_nr(f->io_axmap, block, nr_blocks);
 
 	if ((nr_blocks * min_bs) < io_u->buflen)
 		io_u->buflen = nr_blocks * min_bs;
@@ -122,7 +122,7 @@
 
 	dprint(FD_RANDOM, "get_next_rand_offset: offset %llu busy\n", *b);
 
-	*b = bitmap_next_free(f->io_bitmap, *b);
+	*b = axmap_next_free(f->io_axmap, *b);
 	if (*b == (uint64_t) -1ULL)
 		return 1;
 ret:
@@ -21,12 +21,12 @@
 
 /*
- * The ->io_bitmap contains a map of blocks we have or have not done io
+ * The ->io_axmap contains a map of blocks we have or have not done io
  * to yet. Used to make sure we cover the entire range in a fair fashion.
  */